import { Box, Text } from "@chakra-ui/react";
import { getDashboardStats } from "@/app/lib/dashboard/actions";
import StatsGrid from "./components/StatsGrid";
import { SearchParamProps } from "@/types/searchParams";
import ProjectsGrid from "./components/projectsGrid";

// Fetching data on the server-side in Next.js
const Dashboard = async ({ searchParams }: SearchParamProps) => {
  // Fetch the dashboard stats directly
  const dashboardData = await getDashboardStats();

  // Render loading state if data is not available
  if (!dashboardData) {
    return (
      <Box pt={{ base: "130px", md: "80px", xl: "80px" }}>
        <Text>Loading...</Text>
      </Box>
    );
  }

  return (
    <Box pt={{ base: "130px", md: "80px", xl: "80px" }}>
      {searchParams && searchParams.projects ? (
        <ProjectsGrid />
      ) : (
        <StatsGrid dashboardData={dashboardData} />
      )}
    </Box>
  );
};

export default Dashboard;
